<?php

/**
 * @file
 * Admin helpers.
 */

/**
 * Module settings menu callback function.
 *
 * Form field creation for basic Google Customer Reviews information.
 */
function commerce_google_customer_reviews_admin_settings_form($form_state) {
  $form = array();

  $form['overview'] = array(
    '#markup' => t('Place your company specific information for your Google Customer Reviews here.'),
    '#prefix' => '<p><strong>',
    '#suffix' => '</strong></p>',
  );

  $form['commerce_google_customer_reviews'] = array(
    '#title' => t('Enable Google Customer Reviews'),
    '#description' => t('When enabled, the Google Customer Reviews badge will be enabled, as well as order reviews'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('commerce_google_customer_reviews_enabled', 0),
  );

  $form['merchant_settings'] = array(
    '#title' => t('Merchant Information'),
    '#description' => t('Please retrieve this from the Google Merchant Account.'),
    '#type' => 'fieldset',
    '#collapsable' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['merchant_settings']['merchant_id'] = array(
    '#title' => t('Google Merchant ID'),
    '#description' => t('Place your Google Merchant ID here.'),
    '#type' => 'textfield',
    '#size' => '15',
    '#placeholder' => '123456789',
    '#required' => FALSE,
    '#default_value' => variable_get('commerce_google_customer_reviews_merchant_id'),
  );

  $form['badge_settings'] = array(
    '#title' => t('Badge Information'),
    '#description' => t('Please retrieve this from the Google Customer Reviews integration setup page.'),
    '#type' => 'fieldset',
    '#collapsable' => TRUE,
    '#collapsed' => FALSE,
  );

  $badge_position_options = array(
    'BOTTOM_RIGHT' => t('Bottom Right'),
    'BOTTOM_LEFT' => t('Bottom Left'),
    'USER_DEFINED' => t('User Defined'),
  );

  $form['badge_settings']['badge_position'] = array(
    '#title' => t('Badge Position'),
    '#description' => t('Where would you like your badge to be placed on your website.'),
    '#type' => 'select',
    '#options' => $badge_position_options,
    '#default_value' => variable_get('commerce_google_customer_reviews_badge_location', 'BOTTOM_RIGHT'),
  );

  $form['review_settings'] = array(
    '#title' => t('Review Settings'),
    '#description' => t('See the "Integrate the survey opt-in module" page on Google to view these settings.'),
    '#type' => 'fieldset',
    '#collapsable' => TRUE,
    '#collapsed' => FALSE,
  );

  $reviews_opt_in_style = array(
    'CENTER_DIALOG' => t('Center Dialog: Displayed as a dialog box in the center of the view.'),
    'BOTTOM_RIGHT_DIALOG' => t('Bottom Right Dialog: Displayed as a dialog box at the bottom right of the view.'),
    'BOTTOM_LEFT_DIALOG' => t('Bottom Left Dialog: Displayed as a dialog box at the bottom left of the view.'),
    'TOP_RIGHT_DIALOG' => t('Top Right Dialog: Displayed as a dialog box at the top right of the view.'),
    'TOP_LEFT_DIALOG' => t('Top Left Dialog: Displayed as a dialog box at the top left of the view.'),
    'BOTTOM_TRAY' => t('Bottom Tray: Displayed in the bottom of the view.'),
  );

  $form['review_settings']['opt_in_location'] = array(
    '#title' => t('Opt-In Location'),
    '#description' => t("Specifies how the opt-in module's dialog box is displayed."),
    '#type' => 'radios',
    '#options' => $reviews_opt_in_style,
    '#default_value' => variable_get('commerce_google_customer_reviews_opt_in_location', 'CENTER_DIALOG'),
  );

  $form['review_settings']['estimated_shipping_days'] = array(
    '#title' => t('Estimated Shipping Days'),
    '#description' => t('By default, how many days after an order will the product deliver?'),
    '#type' => 'textfield',
    '#size' => '5',
    '#placeholder' => '14',
    '#required' => FALSE,
    '#default_value' => variable_get('commerce_google_customer_reviews_estimated_shipping_days'),
  );

  $form['review_settings']['estimated_shipping_days_exclude_weekends'] = array(
    '#title' => t('Exclude Weekends in Shipping Days'),
    '#description' => t('This will make your shipping estimate exclude Saturday and Sunday.'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('commerce_google_customer_exclude_weekends', 0),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Settings'),
  );

  return $form;
}

/**
 * Implements form validate callback.
 */
function commerce_google_customer_reviews_admin_settings_form_validate($form, &$form_state) {
  $merchant_id_validator = '/^[0-9]+/';
  $merchant_id = $form_state['values']['merchant_id'];

  // Validate Merchant ID to integers in a row with no spaces.
  if (!preg_match($merchant_id_validator, $merchant_id)) {
    form_set_error('merchant_id', t('Invalid Merchant ID, Please check your work.'));
  }

  // Validate Estimated Shipping Days is an integer of days.
  $estimated_shipping_days_validator = '/^[0-9]+/';
  $estimated_shipping_days = $form_state['values']['estimated_shipping_days'];

  if (!preg_match($estimated_shipping_days_validator, $estimated_shipping_days)) {
    form_set_error('estimated_shipping_days', t('Invalid Shipping Days, please use a number to add to the days from the order date.'));
  }
}

/**
 * Implements form submission handler.
 */
function commerce_google_customer_reviews_admin_settings_form_submit($form, &$form_state) {
  // Rebuild the form.
  $form_state['rebuild'] = TRUE;

  // Save Commerce Google Trusted Store Variables.
  variable_set('commerce_google_customer_reviews_enabled', $form_state['values']['commerce_google_customer_reviews']);
  variable_set('commerce_google_customer_reviews_merchant_id', $form_state['values']['merchant_id']);
  variable_set('commerce_google_customer_reviews_badge_location', $form_state['values']['badge_position']);
  variable_set('commerce_google_customer_reviews_opt_in_location', $form_state['values']['opt_in_location']);
  variable_set('commerce_google_customer_reviews_estimated_shipping_days', $form_state['values']['estimated_shipping_days']);
  variable_set('commerce_google_customer_exclude_weekends', $form_state['values']['estimated_shipping_days_exclude_weekends']);
}
