<?php

/**
 * @file
 * Checkout functions.
 */

/**
 * Implements hook_form_form_id_alter().
 */
function commerce_google_customer_reviews_form_commerce_checkout_form_complete_alter(&$form, &$form_state, $form_id) {
  $gcr_enabled = variable_get('commerce_google_customer_reviews_enabled', 1);

  if ($gcr_enabled) {
    // Get variables from settings page.
    $script_merchant_id = variable_get('commerce_google_customer_reviews_merchant_id');
    $script_shipping_days = variable_get('commerce_google_customer_reviews_estimated_shipping_days');
    $exclude_weekends = variable_get('commerce_google_customer_reviews_exclude_weekends', 0);

    $order = $form_state['order'];

    // Load Profile ID from this order's customer profile.
    $customer_billing_id = $order->commerce_customer_billing['und'][0]['profile_id'];
    // Customer Shipping Information from Profile ID.
    $customer_billing_address = commerce_customer_profile_load($customer_billing_id);
    $customer_billing_country = $customer_billing_address->commerce_customer_address['und'][0]['country'];

    // Gather order and merchant information.
    $merchant_order_id = $order->order_id;

    $customer_email = $order->mail;
    $customer_country = $customer_billing_country;
    // When order is expected at the customer.
    if ($exclude_weekends) {
      $order_est_delivery_date = date('Y-m-d', strtotime(" + {$script_shipping_days} weekdays"));
    }
    else {
      $order_est_delivery_date = date('Y-m-d', strtotime(" + {$script_shipping_days} days"));
    }

    $gcr_checkout_script = 'window.renderOptIn = function() {window.gapi.load(\'surveyoptin\', function() {window.gapi.surveyoptin.render({"merchant_id": ';
    $gcr_checkout_script .= $script_merchant_id;
    $gcr_checkout_script .= ',';
    $gcr_checkout_script .= '"order_id": "';
    $gcr_checkout_script .= $merchant_order_id;
    $gcr_checkout_script .= '",';
    $gcr_checkout_script .= '"email": "';
    $gcr_checkout_script .= $customer_email;
    $gcr_checkout_script .= '",';
    $gcr_checkout_script .= '"delivery_country": "';
    $gcr_checkout_script .= $customer_country;
    $gcr_checkout_script .= '",';
    $gcr_checkout_script .= '"estimated_delivery_date": "';
    $gcr_checkout_script .= $order_est_delivery_date;
    $gcr_checkout_script .= '"});});}';

    // Script Placement for Drupal.
    $gcr_checkout_placement = 'footer';

    // Build an options array for the externally loaded js from Google.
    $gcr_checkout_inject_options = array(
      'type' => 'external',
      'defer' => TRUE,
      'async' => TRUE,
      'scope' => $gcr_checkout_placement,
    );
    drupal_add_js('https://apis.google.com/js/platform.js?onload=renderOptIn', $gcr_checkout_inject_options);
    drupal_add_js($gcr_checkout_script, array('scope' => $gcr_checkout_placement, 'type' => 'inline'));
  }
}
